@@ -74,13 +74,19 @@ class ActionRunResource(resource.Resource):
             return respond(request, None, code=http.NOT_IMPLEMENTED)
 
         action_run = self._job_run.action_runs[self._action_name]
-        try:
-            resp = getattr(action_run, cmd)()
-        except actionrun.Error:
+
+        # An action can only be started if the job run has been started
+        if cmd == 'start' and self._job_run.is_scheduled:
             resp = None
+        else:
+            try:
+                resp = getattr(action_run, cmd)()
+            except actionrun.Error:
+                resp = None
 
         if not resp:
-            msg = "Failed to %s action run %s." % (cmd, action_run)
+            msg = "Failed to %s action run %s is in state %s." % (
+                    cmd, action_run, action_run.state)
         else:
             msg = "Action run now in state %s" % action_run.state.short_name
         return respond(request, {'result': msg})
@@ -519,4 +525,4 @@ class RootResource(resource.Resource):
             'config_href':      request.uri + request.childLink('config'),
             'status_href':      request.uri + request.childLink('status'),
         }
-        return respond(request, response)
\ No newline at end of file
+        return respond(request, response)
