@@ -10,7 +10,7 @@ from tron.serialize import filehandler
 from tron import node
 from tron.actioncommand import ActionCommand
 
-from tron.utils import state, timeutils, proxy
+from tron.utils import state, timeutils, proxy, iteration
 from tron.utils.observer import Observer
 
 log = logging.getLogger(__name__)
@@ -235,7 +235,7 @@ class ActionRun(Observer):
 
         # Transition running to fail unknown because exit status was missed
         if run.is_running:
-            run.machine.transition('fail_unknown')
+            run._done('fail_unknown')
         if run.is_queued or run.is_starting:
             run.fail(None)
         return run
@@ -372,6 +372,10 @@ class ActionRun(Observer):
     def is_active(self):
         return self.is_starting or self.is_running
 
+    def cleanup(self):
+        self.machine.clear_observers()
+        self.cancel()
+
     def __getattr__(self, name):
         """Support convenience properties for checking if this ActionRun is in
         a specific state (Ex: self.is_running would check if self.state is
@@ -400,22 +404,24 @@ class ActionRunCollection(object):
     def __init__(self, action_graph, run_map):
         self.action_graph       = action_graph
         self.run_map            = run_map
-
         # Setup proxies
         self.proxy_action_runs_with_cleanup = proxy.CollectionProxy(
             self.get_action_runs_with_cleanup, [
-                ('is_running',      any,    False),
-                ('is_starting',     any,    False),
-                ('is_scheduled',    any,    False),
-                ('is_cancelled',    any,    False),
-                ('is_active',       any,    False),
-                ('is_queued',       all,    False),
-                ('is_complete',     all,    False),
-                ('queue',           all,    True),
-                ('cancel',          all,    True),
-                ('success',         all,    True),
-                ('fail',            all,    True),
-                ('ready',           all,    True),
+                ('is_running',      any,                    False),
+                ('is_starting',     any,                    False),
+                ('is_scheduled',    any,                    False),
+                ('is_cancelled',    any,                    False),
+                ('is_active',       any,                    False),
+                ('is_queued',       all,                    False),
+                ('is_complete',     all,                    False),
+                ('queue',           iteration.list_all,     True),
+                ('cancel',          iteration.list_all,     True),
+                ('success',         iteration.list_all,     True),
+                ('fail',            iteration.list_all,     True),
+                ('ready',           iteration.list_all,     True),
+                ('cleanup',         iteration.list_all,     True),
+                ('start_time',      iteration.min_filter,   False),
+                ('end_time',        iteration.max_filter,   False),
             ])
 
     def action_runs_for_actions(self, actions):
